#include <avr/io.h>
#include <util/delay.h>
#include <stdlib.h>

#define SDA PC1
#define SCL PC0


void i2c_init(void)
{
	TWCR|=(1<<TWEN);			// Pin1 an Port C wird SCL, Pin2 wird SDA
	
	DDRC&=~(1<<SDA);
	DDRC&=~(1<<SCL);
	PORTC&=~(1<<SDA);
	PORTC&=~(1<<SCL);
}

void i2c_start(void)
{
	DDRC|=(1<<SDA);		// Startkommando - SCL ist high und SDA wird auf low gezogen
	_delay_ms(10);
	
	DDRC|=(1<<SCL);		
	_delay_ms(10);
}
	
	
void i2c_stop(void)
{
	DDRC&=~(1<<SCL);		// Stoppkommando - SCL ist high und SDA wird auch auf high gesetzt
	_delay_ms(10);
	
	DDRC&=~(1<<SDA);
	_delay_ms(10);
}


unsigned char i2c_transmit_byte(unsigned char byte)
{
	for(uint8_t i=0;i<8;i++)
	{
		if(byte&0x80)	DDRC&=~(1<<SDA);
		DDRC&=~(1<<SCL);						// Wenn if-Bedingung erfllt war - 1 gesendet, falls nicht, 0 gesendet
		_delay_ms(10);
		DDRC|=(1<<SCL);						
		DDRC|=(1<<SDA);
		_delay_ms(10);
		byte<<=1;								
	}
	
	DDRC&=~(1<<SDA);
	DDRC&=~(1<<SCL);
	_delay_ms(10);
	unsigned char ack=PINC&(1<<SDA);			// Acknowledge wird empfangen
	DDRC|=(1<<SCL);							
	DDRC|=(1<<SDA);
	_delay_ms(10);
	if(ack) ack=1;
	return ack;
}


unsigned char i2c_receive_byte(void)
{
	unsigned char daten=0;
	
	for(uint8_t i=0;i<8;i++)
	{
		daten <<= 1;
		DDRC&=~(1<<SCL);
		_delay_us(60);
		if(PINC&(1<<SDA)) daten|=1;			// Falls an SDA eine Spannung gemessen wird, wird eine 1 geschrieben
		DDRC|=(1<<SCL);
		_delay_ms(10);
	}
	DDRC&=~(1<<SDA);							// Ack geben
	DDRC&=~(1<<SCL);
	_delay_ms(10);
	DDRC|=(1<<SCL);
	_delay_ms(10);
	return daten;
}

void i2c_ack(void)
{
	DDRC&=~(1<<SDA);							// Ack geben
	DDRC&=~(1<<SCL);
	_delay_ms(10);
	DDRC|=(1<<SCL);
	_delay_ms(10);
}